C Subroutine MAP_STEEL_STREN
C
C Provided by :-
C
C  H.K.D.H. Bhadeshia,
C  Phase Transformations Group,
C  Department of Materials Science and Metallurgy,
C  University of Cambridge,
C  Cambridge, U.K.
C
C Purpose :-
C
C Given the composition, volume fraction of allotriomorphic ferrite and volume 
C fraction of acicular ferrite of a steel weld, this routine calculates the 
C overall yield strength, the overall tensile strength and the paraequilibrium 
C temperature of the material [1,2]. It also calculates the secondary hardening 
C effect of molybdenum and gives as output parameters the strength components  
C due to the microstructure and each element present.
C The secondary hardening effect of molybdenum is accounted for using Evans' 
C MMA molybdenum data [3], and the assumption that molybdenum does not
C influence the fractions of primary and secondary regions in any exceptional
C way. There is an arbitrary limit before the carbon-molybdenum effect
C manifests itself.</p>
C
C
C References :-
C
C 1. Computer Technology in Welding, pt.II.
C
C 2. A. A. B. Sugden and H. K. D. H. Bhadeshia, "A Model for the Prediction of 
C    Strength in Steel Welds", Metallurgical Transactions A, Vol. 19, 1988,
C    pp. 1597-1602
C
C 3. H.K.D.H. Bhadeshia, Mathematical Modelling of Weld Phenomena I, 
C    eds H. Cerjak and K.E. Easterling, The Institute of Materials, London, 
C    1993, pp 109-182.
C
C Input parameters :-
C
C COMP contains the concentrations by percentage weight of carbon, silicon,
C  manganese, nickel, molydenum, chromium, vanadium, and iron.
C NITPPM is the nitrogen concentration in parts per million by weight. If it
C  is zero on input, then it is calculated using the method in [1].
C VOLFRA is the volume fraction of allotriomorphic ferrite.
C VACIC is the volume fraction of acicular ferrite.
C
C Output parameters :-
C
C VP is the primary microstructure at the interpass temperature.
C VS is the secondary microstructure at the interpass temperature.
C SIGP is the strength of the primary microstructure (in MPa).
C SIGS is the strength of the secondary microstructure (in MPa).
C SIGY is the overall yield strength (in MPa).
C UTS is the overall tensile strength (in MPa).
C AE3 is the paraequilibrium temperature.
C RATIO is the ratio of yield to tensile strength.
C ENTR is the scatter in toughness (0 is low, 1 is high).
C ST contains the components of strength due to:-
C   ST(1)  - allotriomorphic ferrite.
C   ST(2)  - acicular ferrite.
C   ST(3)  - Widmanstatten ferrite.
C   ST(4)  - nitrogen.
C   ST(5)  - manganese.
C   ST(6)  - silicon.
C   ST(7)  - nickel.
C   ST(8)  - molybdenum.
C   ST(9)  - chronium.
C   ST(10) - vanadium.
C   ST(11) - iron.
C   ST(12) - secondary hardening effect of Mo.
C
C Auxiliary subroutine :-
C
C   MAP_STEEL_AA3
C
C Copyright Dr. H. K. D. H. Bhadeshia, University of Cambridge
C December 1987
C Version 1.4
C
C NITPPM = Nitrogen concentration in ppmw. If zero, then calculated,
C according to Computer Technology in Welding, pt.II
C
       SUBROUTINE MAP_STEEL_STREN(COMP, NITPPM, VOLFRA, VACIC,
     &  VP, VS, SIGP, SIGS, SIGY, UTS, AE3, RATIO, ENTR, ST)
C
       IMPLICIT NONE
C
C Input/output arguments :-
C
       DOUBLE PRECISION COMP(8), ST(12)
       DOUBLE PRECISION AE3, ENTR, NITPPM, RATIO, SIGP, SIGS, SIGY, UTS
       DOUBLE PRECISION VACIC, VOLFRA, VP, VS, R
C
C Local variables :-
C
       DOUBLE PRECISION VOLW, MOSEC, CSEC, CDUM, RATIO, ENTR
       INTEGER I1, I2, I3
C
       PARAMETER(R=8.31451D+00)
       I1=873
       I2=1173
       I3=30
C
C Begin subroutine proper :-
C
       CALL MAP_STEEL_AA3(COMP,AE3,R,I1,I2,I3)
C
       VP = 3.313 - 0.0037*AE3
       IF(VP .GT. 1.0) THEN
         GOTO 10
       END  IF
       GOTO 20
C
10     CONTINUE
       VP   = 1.0
C
20     CONTINUE
       VS   = 1.0-VP
       VOLW = 1.0-VOLFRA-VACIC
C
       ST(1) = VOLFRA*27.0
       ST(2) = VACIC*402.0
       ST(3) = VOLW*486.0
       ST(4) = NITPPM*42.8/100.0
       ST(5) = COMP(3)*40.8
       ST(6) = COMP(2)*94.5
       ST(7) = COMP(4)*33.2
C
C 2 October 1993; modification to account for the secondary hardening effect
C   of Mo, using Evans's MMA Mo data and the assumption that Mo does not
C   influence the fractions of primary and secondary regions in any 
C   exceptional way.  There is an arbitrary limit before the C-Mo effect
C   manifests, and there is a maximum limit to the C-Mo effect.  See H.K.D.H. 
C   Bhadeshia, <cite>Mathematical Modelling of Weld Phenomena I</cite>, eds 
C   H. Cerjak and K.E. Easterling, The Institute of Materials, London, 1993,
C   pp 109-182.C
C
C MOSEC and CSEC are the additional contributions due to secondary hardening
C
       MOSEC = 132.00*COMP(5)
       IF(COMP(1) .GE. 0.037 .AND. COMP(5) .GE. 0.10D+00) THEN
          CDUM = COMP(1)
          IF(COMP(1) .GE. 0.05) THEN
             CDUM = 0.05
          END  IF
          CSEC = (CDUM - 0.037)*4700.0
       ELSE
          CSEC = 0.0D+00
       ENDIF
C
       ST(8)  = COMP(5)*16.0 + MOSEC + CSEC
       ST(9)  = COMP(6)*7.5
       ST(10) = COMP(7)*4.5
       ST(11) = 219.0
       ST(12) = 68.0
C
       SIGS = ST(4)+ST(5)+ST(6)+ST(7)+ST(8)+ST(9)+
     &        ST(10)+ST(11)+ST(12)
       SIGP = ST(1)+ST(2)+ST(3)+ST(4)+ST(5)+ST(6)+
     &        ST(7)+ST(8)+ST(9)+ST(10)+ST(11)
       SIGY = VS*SIGS+VP*SIGP
C
       ST(1)  = ST(1) *VP
       ST(2)  = ST(2) *VP
       ST(3)  = ST(3) *VP
       ST(12) = ST(12)*VS
C
       UTS   = 112.4+0.9153*SIGY
       RATIO = SIGY/UTS
C
       IF(VACIC .EQ. 1.0D+00 .OR. VOLFRA .EQ. 1.0D+00 .OR .
     & VOLW .EQ. 1.00) THEN
          GOTO 30
       END  IF
C
       ENTR = (VOLFRA*LOG(VOLFRA+1.0D-06) +
     & VACIC*LOG(VACIC+1.0D-06)
     & + VOLW*LOG(VOLW+1.0D-06))/(LOG(1.0D+00/3.0D+00))
       GOTO 40
C
30     CONTINUE
       ENTR=0.0D+00
C
40     CONTINUE
       RETURN
       END
